@@ -14,3 +14,10 @@ def get_build_config(usecase_filename):
         # print(build_config)
         id = build_config["id"]
         return build_config, id
+
+
+def get_build_config_metadata(build_config):
+    build_config_metadata = {}
+    if "metadata" in build_config:
+        build_config_metadata = build_config["metadata"]
+    return build_config_metadata
