@@ -1,12 +1,5 @@
-import datetime
-import json
 import logging
-import math
 import pathlib
-import sys
-import tempfile
-import shutil
-import traceback
 import docker
 import redis
 import os
@@ -14,56 +7,27 @@ from pathlib import Path
 
 from redisbench_admin.profilers.profilers_local import (
     check_compatible_system_and_kernel_and_prepare_profile,
-    profilers_start_if_required,
-    local_profilers_platform_checks,
-    profilers_stop_if_required,
 )
-from docker.models.containers import Container
-
-from redisbench_admin.run.common import (
-    get_start_time_vars,
-    prepare_benchmark_parameters,
-)
-from redisbench_admin.run.grafana import generate_artifacts_table_grafana_redis
-from redisbench_admin.utils.benchmark_config import (
-    get_final_benchmark_config,
-)
-from redisbench_admin.run.redistimeseries import (
-    timeseries_test_sucess_flow,
-    datasink_profile_tabular_data,
-)
-from redisbench_admin.run.run import calculate_client_tool_duration_and_check
-from redisbench_admin.utils.benchmark_config import (
-    extract_redis_dbconfig_parameters,
-)
-from redisbench_admin.utils.local import get_local_run_full_filename
-from redisbench_admin.utils.results import post_process_benchmark_results
 
 from redis_benchmarks_specification.__common__.env import (
     LOG_FORMAT,
     LOG_DATEFMT,
     LOG_LEVEL,
     STREAM_KEYNAME_NEW_BUILD_EVENTS,
-    STREAM_GH_NEW_BUILD_RUNNERS_CG,
     REDIS_HEALTH_CHECK_INTERVAL,
     REDIS_SOCKET_TIMEOUT,
-    S3_BUCKET_NAME,
 )
 from redis_benchmarks_specification.__common__.package import (
     get_version_string,
     populate_with_poetry_data,
 )
-from redis_benchmarks_specification.__common__.spec import (
-    extract_client_cpu_limit,
-    extract_client_container_image,
-    extract_client_tool,
-    extract_build_variant_variations,
-)
 from redis_benchmarks_specification.__self_contained_coordinator__.args import (
     create_self_contained_coordinator_args,
 )
-from redis_benchmarks_specification.__self_contained_coordinator__.artifacts import (
-    restore_build_artifacts_from_test_details,
+from redis_benchmarks_specification.__self_contained_coordinator__.runners import (
+    build_runners_consumer_group_create,
+    get_runners_consumer_group_name,
+    process_self_contained_coordinator_stream,
 )
 from redis_benchmarks_specification.__setups__.topologies import get_topologies
 
@@ -230,34 +194,6 @@ def main():
         )
 
 
-def build_runners_consumer_group_create(conn, running_platform, id="$"):
-    consumer_group_name = get_runners_consumer_group_name(running_platform)
-    logging.info("Will use consumer group named {}.".format(consumer_group_name))
-    try:
-        conn.xgroup_create(
-            STREAM_KEYNAME_NEW_BUILD_EVENTS,
-            consumer_group_name,
-            mkstream=True,
-            id=id,
-        )
-        logging.info(
-            "Created consumer group named {} to distribute work.".format(
-                consumer_group_name
-            )
-        )
-    except redis.exceptions.ResponseError:
-        logging.info(
-            "Consumer group named {} already existed.".format(consumer_group_name)
-        )
-
-
-def get_runners_consumer_group_name(running_platform):
-    consumer_group_name = "{}-{}".format(
-        STREAM_GH_NEW_BUILD_RUNNERS_CG, running_platform
-    )
-    return consumer_group_name
-
-
 def self_contained_coordinator_blocking_read(
     conn,
     datasink_push_results_redistimeseries,
@@ -414,16 +350,9 @@ def process_self_contained_coordinator_stream(
                 logging.info(
                     "Restoring docker image: {} from {}".format(run_image, airgap_key)
                 )
-                if conn.exists(airgap_key):
-                    airgap_docker_image_bin = conn.get(airgap_key)
-                    images_loaded = docker_client.images.load(airgap_docker_image_bin)
-                    logging.info("Successfully loaded images {}".format(images_loaded))
-                else:
-                    logging.error(
-                        "docker image {} was not present on key {}".format(
-                            run_image, airgap_key
-                        )
-                    )
+                airgap_docker_image_bin = conn.get(airgap_key)
+                images_loaded = docker_client.images.load(airgap_docker_image_bin)
+                logging.info("Successfully loaded images {}".format(images_loaded))
 
             for test_file in testsuite_spec_files:
                 redis_containers = []
@@ -945,100 +874,3 @@ def get_benchmark_specs(testsuites_folder):
         "Running all specified benchmarks: {}".format(" ".join([str(x) for x in files]))
     )
     return files
-
-
-def extract_build_info_from_streamdata(testDetails):
-    use_git_timestamp = False
-    git_timestamp_ms = None
-    git_version = None
-    git_branch = None
-    metadata = None
-    build_variant_name = None
-    fields = [fieldname.decode() for fieldname in testDetails.keys()]
-    logging.info("Fields on stream {}".format(fields))
-    git_hash = testDetails[b"git_hash"]
-    if b"use_git_timestamp" in testDetails:
-        use_git_timestamp = bool(testDetails[b"use_git_timestamp"].decode())
-    if b"git_timestamp_ms" in testDetails:
-        git_timestamp_ms = int(testDetails[b"git_timestamp_ms"].decode())
-    if b"id" in testDetails:
-        build_variant_name = testDetails[b"id"]
-        if type(build_variant_name) == bytes:
-            build_variant_name = build_variant_name.decode()
-    if b"git_branch" in testDetails:
-        git_branch = testDetails[b"git_branch"]
-        if type(git_branch) == bytes:
-            git_branch = git_branch.decode()
-    if b"git_version" in testDetails:
-        git_version = testDetails[b"git_version"]
-        if type(git_version) == bytes:
-            git_version = git_version.decode()
-    if type(git_hash) == bytes:
-        git_hash = git_hash.decode()
-    logging.info("Received commit hash specifier {}.".format(git_hash))
-    build_artifacts_str = "redis-server"
-    build_image = testDetails[b"build_image"].decode()
-    run_image = build_image
-    if b"run_image" in testDetails:
-        run_image = testDetails[b"run_image"].decode()
-        logging.info("detected run image info {}.".format(run_image))
-    else:
-        logging.info("using build image info {}.".format(build_image))
-    if b"build_artifacts" in testDetails:
-        build_artifacts_str = testDetails[b"build_artifacts"].decode()
-    build_artifacts = build_artifacts_str.split(",")
-    if b"metadata" in testDetails:
-        metadata = json.loads(testDetails[b"metadata"].decode())
-    return (
-        build_variant_name,
-        metadata,
-        build_artifacts,
-        git_hash,
-        git_branch,
-        git_version,
-        run_image,
-        use_git_timestamp,
-        git_timestamp_ms,
-    )
-
-
-def generate_cpuset_cpus(ceil_db_cpu_limit, current_cpu_pos):
-    previous_cpu_pos = current_cpu_pos
-    current_cpu_pos = current_cpu_pos + int(ceil_db_cpu_limit)
-    db_cpuset_cpus = ",".join(
-        [str(x) for x in range(previous_cpu_pos, current_cpu_pos)]
-    )
-    return db_cpuset_cpus, current_cpu_pos
-
-
-def extract_db_cpu_limit(topologies_map, topology_spec_name):
-    topology_spec = topologies_map[topology_spec_name]
-    db_cpu_limit = topology_spec["resources"]["requests"]["cpus"]
-    ceil_db_cpu_limit = math.ceil(float(db_cpu_limit))
-    return ceil_db_cpu_limit
-
-
-def generate_standalone_redis_server_args(
-    binary, port, dbdir, configuration_parameters=None
-):
-    added_params = ["port", "protected-mode", "dir"]
-    # start redis-server
-    command = [
-        binary,
-        "--protected-mode",
-        "no",
-        "--port",
-        "{}".format(port),
-        "--dir",
-        dbdir,
-    ]
-    if configuration_parameters is not None:
-        for parameter, parameter_value in configuration_parameters.items():
-            if parameter not in added_params:
-                command.extend(
-                    [
-                        "--{}".format(parameter),
-                        parameter_value,
-                    ]
-                )
-    return command
